#!/bin/bash

########################################
# Author: Bill Swords
# ScriptName: Wallpaper Rotator
# Version: 1.0
# Creation Date: 04/04/24 16:58:14
# Last Updated: 04/04/24 16:58:14
# Description: Configures wallpaper-rotator
# Website: https://www.lovinlinux.com
########################################

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.

CONFIG_FILE="$HOME/.config/wallpaper-rotator/wallpaper.conf"
FIRSTRUN="$(grep firstrun: ${CONFIG_FILE} | awk -F ':' '{print $2}')"

function firstrun() {
touch "$HOME/.config/autostart/wallpaperStart.desktop"

echo "[Desktop Entry]
Type=Application
Exec=/usr/local/bin/wallpaperStart.sh
Hidden=false
Name[en_US]=Wallpaper Rotator
Name=Wallpaper Rotator
Comment[en_US]=Start the Wallpaper Rotator
Comment=Start the Wallpaper Rotator
X-MATE-Autostart-Delay=1" > "$HOME/.config/autostart/wallpaperStart.desktop"
}
export -f firstrun

if [ ! -f "$CONFIG_FILE" ];then
  touch "$CONFIG_FILE"
  echo "folder:$HOME/Pictures" > $CONFIG_FILE
  echo "interval:30" >> $CONFIG_FILE
  echo "active:0" >> $CONFIG_FILE
  echo "style:scaled" >> $CONFIG_FILE
  echo "firstrun:0" >> $CONFIG_FILE
fi
if [ -z "$(cat ${CONFIG_FILE})" ];then
  echo "folder:$HOME/Pictures" > $CONFIG_FILE
  echo "interval:30" >> $CONFIG_FILE
  echo "active:0" >> $CONFIG_FILE
  echo "style:scaled" >> $CONFIG_FILE
  echo "firstrun:0" >> $CONFIG_FILE
fi

if [ "$FIRSTRUN" -eq "0" ];then
    firstrun
    mkdir $HOME/.config/wallpaper-rotator
    touch $CONFIG_FILE
    echo "folder:$HOME/Pictures" > $CONFIG_FILE
    echo "interval:30" >> $CONFIG_FILE
    echo "active:0" >> $CONFIG_FILE
    echo "style:scaled" >> $CONFIG_FILE
    echo "firstrun:1" >> $CONFIG_FILE
fi

# Read default info from the file
function read_file() {
  RUN="$(grep active: ${CONFIG_FILE} | awk -F ':' '{print $2}')"
  FOLDER="$(grep folder: ${CONFIG_FILE} | awk -F ':' '{print $2}')"
  if [[ "${FOLDER}" == "" ]]; then
    FOLDER="$HOME/Pictures"
  fi
  INTERVAL="$(grep interval: ${CONFIG_FILE} | awk -F ':' '{print $2}')"
  if [[ "${INTERVAL}" == "" ]]; then
    INTERVAL="30"
  fi
  STYLE="$(grep style: ${CONFIG_FILE} | awk -F ':' '{print $2}')"
  if [ "$STYLE" == "wallpaper" ];then
#    ADD THE STYLES HERE IN A ROLLING LIST ACCORDING TO THE CURRENTLY ASSIGNED STYLE
    DEFSTYLE="Tile!Zoom!Center!Scale!Stretch!Span"
  elif [ "$STYLE" == "zoom" ];then
    DEFSTYLE="Zoom!Center!Scale!Stretch!Span!Tile"
  elif [ "$STYLE" == "cetered" ];then
    DEFSTYLE="Center!Scale!Stretch!Span!Tile!Zoom"
  elif [ "$STYLE" == "scaled" ];then
    DEFSTYLE="Scale!Stretch!Span!Tile!Zoom!Center"
  elif [ "$STYLE" == "stretched" ];then
    DEFSTYLE="Stretch!Span!Tile!Zoom!Center!Scale"
  elif [ "$STYLE" == "spanned" ];then
    DEFSTYLE="Span!Tile!Zoom!Center!Scale!Stretch"    
  fi
  
  if [ "$RUN" -eq "0" ];then 
    DEFSTAT="Enabled!Disabled"
  else
    DEFSTAT="Disabled!Enabled"
  fi
}
export -f read_file

# Create the about dialog
function about_dlg() {
  zenity --text-info --title="About Wallpaper Rotator" --width 375 --height 400 --html --url="https://www.lovinlinux.com/about-wallpaper.html"
# exec 2> >(grep -v GtkDialog >&2)

}
export -f about_dlg

# Get the values and post to the CONFIG_FILE
function write_file() {
  SETDIR=$(echo $CONFIG | awk 'BEGIN {FS="|" } { print $1 }')
  SETSTYLE=$(echo $CONFIG | awk 'BEGIN {FS="|" } { print $2 }')
  SETINTERVAL=$(echo $CONFIG | awk 'BEGIN {FS="|" } { print $3 }')
  SETSTATUS=$(echo $CONFIG | awk 'BEGIN {FS="|" } { print $4 }')
  
  if [ "$SETSTATUS" == "Enabled" ];then
    SETSTATUSINT="0"
  else
    SETSTATUSINT="1"
  fi
  # Sort out style
  if [ "$SETSTYLE" == "Tile" ];then
    SETMYSTYLE="wallpaper"
  elif [ "$SETSTYLE" == "Zoom" ];then
    SETMYSTYLE="zoom"
  elif [ "$SETSTYLE" == "Center" ];then
    SETMYSTYLE="centered"
  elif [ "$SETSTYLE" == "Scale" ];then
    SETMYSTYLE="scaled"
  elif [ "$SETSTYLE" == "Stretch" ];then
    SETMYSTYLE="stretched"
  elif [ "$SETSTYLE" == "Span" ];then
    SETMYSTYLE="spanned"
  fi  
  
  sed -i "1s|.*|folder:${SETDIR}|" "$CONFIG_FILE"
  sed -i "2s|.*|interval:${SETINTERVAL}|" "$CONFIG_FILE"
  sed -i "3s|.*|active:${SETSTATUSINT}|" "$CONFIG_FILE"
  sed -i "4s|.*|style:${SETMYSTYLE}|" "$CONFIG_FILE"
  sed -i "5s|.*|firstrun:1|" "$CONFIG_FILE"
}
export -f write_file

function restart() {
  killall wallpaperRotator
  wallpaperRotator &
}
export -f restart

# Start the config dialog
if [ -z "$(cat ${CONFIG_FILE})" ];then 
  echo "Config file is empty"
  DEFSTAT="Enabled!Disabled"
else
  echo "We made it this far"
  read_file
fi 
  # values for picture-options: ‘none’, ‘wallpaper’, ‘centered’, ‘scaled’, ‘stretched’, ‘zoom’, ‘spanned’ #            
CONFIG=$(yad --form --title "Wallpaper Rotator Config" --width 350 \
            --field="Image Directory:DIR" \
            --field="Image Style:CB" \
            --field="Interval (seconds):NUM" \
            --field="Status:CB" \
            --button="About!gtk-about":"bash -c about_dlg" \
            --button="Cancel!gtk-cancel":1 \
            --button="Save!gtk-save":0 \
             "$FOLDER" "$DEFSTYLE" "$INTERVAL!15..3600!15" "$DEFSTAT"
        )
        saveit=$?
if [ "$saveit" -eq "0" ];then
  write_file
  restart
else
  exit
fi

echo $CONFIG

exit
